@@ -11,13 +11,20 @@
 /**
  * @file hotkeys.h
  * Header for hotkeys.c.
- * @brief header for hotkeys.c
+ * @brief Header for hotkeys.c.
  */
 
-#ifndef HOTKEYS_H_
-#define HOTKEYS_H_
+#ifndef _HOTKEYS_H_
+#define _HOTKEYS_H_
 
-void add_filter(void);
-void grab_keys(int, int, int, int, int, int, int);
+#include "audio.h"
 
-#endif				// HOTKEYS_H
+typedef struct hotkeys Hotkeys;
+
+Hotkeys *hotkeys_new(Audio *audio);
+void hotkeys_free(Hotkeys *hotkeys);
+void hotkeys_reload(Hotkeys *hotkeys);
+void hotkeys_bind(Hotkeys *hotkeys);
+void hotkeys_unbind(Hotkeys *hotkeys);
+
+#endif				// _HOTKEYS_H
