@@ -204,7 +204,7 @@ struct prefs_dialog {
 	GtkWidget *custom_entry;
 	/* Hotkeys panel */
 	GtkWidget *hotkeys_enable_check;
-	GtkWidget *hotkeys_table;
+	GtkWidget *hotkeys_grid;
 	GtkWidget *hotkeys_mute_eventbox;
 	GtkWidget *hotkeys_mute_label;
 	GtkWidget *hotkeys_up_eventbox;
@@ -212,7 +212,7 @@ struct prefs_dialog {
 	GtkWidget *hotkeys_down_eventbox;
 	GtkWidget *hotkeys_down_label;
 	/* Notifications panel */
-#ifdef HAVE_LIBN
+#ifdef WITH_LIBNOTIFY
 	GtkWidget *noti_vbox_enabled;
 	GtkWidget *noti_enable_check;
 	GtkWidget *noti_timeout_label;
@@ -301,7 +301,7 @@ void
 on_hotkeys_enable_check_toggled(GtkToggleButton *button, PrefsDialog *dialog)
 {
 	gboolean active = gtk_toggle_button_get_active(button);
-	gtk_widget_set_sensitive(dialog->hotkeys_table, active);
+	gtk_widget_set_sensitive(dialog->hotkeys_grid, active);
 }
 
 /**
@@ -387,7 +387,7 @@ on_hotkey_event_box_button_press_event(GtkWidget *widget, GdkEventButton *event,
  * @param button the button which received the signal.
  * @param dialog user data set when the signal handler was connected.
  */
-#ifdef HAVE_LIBN
+#ifdef WITH_LIBNOTIFY
 void
 on_noti_enable_check_toggled(GtkToggleButton *button, PrefsDialog *dialog)
 {
@@ -485,7 +485,7 @@ prefs_dialog_retrieve(PrefsDialog *dialog)
 	active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dvc));
 	prefs_set_boolean("DrawVolMeter", active);
 
-	// volume meter positon
+	// volume meter position
 	GtkWidget *vmps = dialog->vol_meter_pos_spin;
 	gint vmpos = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(vmps));
 	prefs_set_integer("VolMeterPos", vmpos);
@@ -581,7 +581,7 @@ prefs_dialog_retrieve(PrefsDialog *dialog)
 	prefs_set_integer("VolDownMods", mods);
 
 	// notifications
-#ifdef HAVE_LIBN
+#ifdef WITH_LIBNOTIFY
 	GtkWidget *nc = dialog->noti_enable_check;
 	gint noti_spin;
 	active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(nc));
@@ -761,7 +761,7 @@ prefs_dialog_populate(PrefsDialog *dialog)
 	(GTK_TOGGLE_BUTTON(dialog->hotkeys_enable_check), dialog);
 
 	// notifications
-#ifdef HAVE_LIBN
+#ifdef WITH_LIBNOTIFY
 	gtk_toggle_button_set_active
 	(GTK_TOGGLE_BUTTON(dialog->noti_enable_check),
 	 prefs_get_boolean("EnableNotifications", FALSE));
@@ -859,7 +859,7 @@ prefs_dialog_create(GtkWindow *parent, Audio *audio, Hotkeys *hotkeys,
 	 */
 	gtk_notebook_append_page
 	(GTK_NOTEBOOK(gtk_builder_get_object(builder, "notebook")),
-#ifdef HAVE_LIBN
+#ifdef WITH_LIBNOTIFY
 	 GTK_WIDGET(gtk_builder_get_object(builder, "noti_vbox_enabled")),
 #else
 	 GTK_WIDGET(gtk_builder_get_object(builder, "noti_vbox_disabled")),
@@ -897,7 +897,7 @@ prefs_dialog_create(GtkWindow *parent, Audio *audio, Hotkeys *hotkeys,
 	assign_gtk_widget(builder, dialog, custom_entry);
 	// Hotkeys panel
 	assign_gtk_widget(builder, dialog, hotkeys_enable_check);
-	assign_gtk_widget(builder, dialog, hotkeys_table);
+	assign_gtk_widget(builder, dialog, hotkeys_grid);
 	assign_gtk_widget(builder, dialog, hotkeys_mute_eventbox);
 	assign_gtk_widget(builder, dialog, hotkeys_mute_label);
 	assign_gtk_widget(builder, dialog, hotkeys_up_eventbox);
@@ -905,7 +905,7 @@ prefs_dialog_create(GtkWindow *parent, Audio *audio, Hotkeys *hotkeys,
 	assign_gtk_widget(builder, dialog, hotkeys_down_eventbox);
 	assign_gtk_widget(builder, dialog, hotkeys_down_label);
 	// Notifications panel
-#ifdef HAVE_LIBN
+#ifdef WITH_LIBNOTIFY
 	assign_gtk_widget(builder, dialog, noti_vbox_enabled);
 	assign_gtk_widget(builder, dialog, noti_enable_check);
 	assign_gtk_widget(builder, dialog, noti_timeout_spin);
